<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category template manager
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 26, 2013 11:36:11 AM
 * @version $Rev$
 */

/**
 * Settings class
 * Used to create an WP page tab to list, edit, delete and add Candidate Page sources
 */
class Admin_Sources_Candidates extends WP_Page {

    protected $interfacer = null;
    private $source_type = 'candidate';

    public function __construct() {
        $this->interfacer = WP_Interfacer::getInstance();
    }

    public function getCapability() {
        return WP_Constants::CAPABILITY_ADMIN;
    }

    public function getMenuSlug() {
        return 'carerix_sources_candidates_page';
    }

    public function getMenuTitle() {
        return 'Candidates';
    }

    public function getPageTitle() {
        return 'Candidates';
    }

    /**
     * switch for the different actions possible on this page
     */
    public function page() {
		// $input_data = filter_input_array(INPUT_GET, FILTER_FLAG_STRIP_BACKTICK | FILTER_FLAG_ALLOW_OCTAL);
	    $input_data = map_deep( $_GET, 'sanitize_textarea_field' );
        switch ($input_data['action']) {
            case 'edit':
                $this->sourceScreen($input_data['id']);
                break;
            case 'add':
                $this->sourceScreen();
                break;
            case 'delete':
                $this->deleteSource($input_data['id']);
                break;
            case 'association':
                $this->deleteAssociatedPosts($input_data['id']);
            case 'list':
            default:
                $this->listSources($input_data['message']);
                break;
        }
    }

    /**
     * Saves and edits a Candidate source.
     * 
     * @param mixed $id integer or boolean false
     */
    private function sourceScreen($id = false) {
        // $input_data = filter_input_array(INPUT_POST, FILTER_FLAG_STRIP_BACKTICK | FILTER_FLAG_ALLOW_OCTAL);
	    $input_data = map_deep( wp_unslash($_POST), 'sanitize_textarea_field' );

        $data = array();
        if (count($input_data)) {
            if (trim($input_data['name']) != '') {
                $input_data['introtext'] = $_POST['introtext'];  // Will be sanitized by wp_editor function 
                unset($input_data['save']);
                $backup_data = $input_data;
                $id = false;
                if (isset($input_data['id']))
                    $id = $input_data['id'];

                $candidateSource = new Entity_Source_Candidate($id);
                $candidateSource->save($input_data);

                $id = $candidateSource->getID();
                $data['edit_data'] = $backup_data;
            }
            else {
                $data['page_error'] = true;
                $data['title_error'] = true;
            }
        }

        if ($id) {
            $candidateSource = new Entity_Source_Candidate($id);

            $sourceData = $candidateSource->getData();
            $sourceData['settings'] = unserialize($sourceData['settings']);

            if ( count($input_data) ) {
                try {
                    $cronRunner = new Environment_CronRunner();
                } catch (Exception $ex) {
                    $data['page_error'] = true;
                    $data['sync_error'] = true;
                }
            }

            $data['edit_data'] = $sourceData;
        }
        if (!isset($data['page_error']) && count($input_data) ) {
            $data['success'] = true;
        }
        $data['cancel_link'] = $this->createActionLink('list');
        $template = new Utils_Template('admin/sources/candidates_edit');
        $template->with($data)->display();
    }

    private function getFrontendPage($source_id) {
        $ents = $this->interfacer->entities_get_where_property('_carerix_candidate_page', $source_id);
        if (isset($ents[0]) && isset($ents[0]->post_id))
            return $this->interfacer->get_post_permalink($ents[0]->post_id);

        return '';
    }

    static public function ajaxSaveSource($input_data) {
        $data = array();
        if (count($input_data)) {
            if (trim($input_data['name']) != '') {
                $input_data['introtext'] = stripslashes($input_data['introtext']);
                $input_data['posttemplate'] = stripslashes($input_data['posttemplate']);

                $id = false;

                if (isset($input_data['id']))
                    $id = $input_data['id'];

                $candidateSource = new Entity_Source_Candidate($id);
                $candidateSource->save($input_data);

                $id = $candidateSource->getID();
            }
            else {
                $data['page_error'] = true;
                $data['title_error'] = true;
            }
        }


        if ($id) {
            $data['id'] = $id;
        }

        if (!isset($data['page_error']) && count($input_data)) {
            $data['success'] = true;
        }
        return $data;
    }

    /**
     * Displays a list of all candidate sources in a table.
     */
    private function listSources($message = '') {
        $data = array();

        $sourcesTable = new WP_Table(Environment_Installation::TABLE_SOURCES);

        $candidateSources = $sourcesTable->getByType($this->source_type);

        foreach ($candidateSources as &$candidateSource) {
            $candidateSource['settings'] = unserialize($candidateSource['settings']);
            $candidateSource['editLink'] = $this->getSourceEditLink($candidateSource['id']);
            $candidateSource['deleteLink'] = $this->getSourceDeleteLink($candidateSource['id']);
            $candidateSource['pageLink'] = $this->getFrontendPage($candidateSource['id']);
        }

        $data['add_new'] = $this->createActionLink('add');
        $data['candidateSources'] = $candidateSources;

        switch ($message) {
            case 'yes':
                $temp = new Utils_Template('admin/sources/confirmation');
                $temp->with(array('type' => 'yes'))->display();
                break;
            case 'no':
                $temp = new Utils_Template('admin/sources/confirmation');
                $temp->with(array('type' => 'no'))->display();
                break;
            default:
                break;
        }

        $template = new Utils_Template('admin/sources/candidates');
        $template->with($data)->display();
    }

    private function deleteSource($id) {
        $sourcesTable = new WP_Table(Environment_Installation::TABLE_SOURCES);
        $sourcesTable->delete($id);

        $data = array();
        $data['source_id'] = $id;
        $data['delete_link'] = $this->getSourceAssociationDeleteLink($id);
        $data['tab_link'] = $this->getTabLink();

        $template = new Utils_Template('admin/sources/delete_associations');
        $template->with($data)->display();
    }

    private function deleteAssociatedPosts($sourceID) {
        $entities = $this->interfacer->entities_get_where_property('source', $sourceID);
        foreach ($entities as $entity) {
            $this->interfacer->entity_delete($entity->post_id);
        }
    }

    private function getSourceAssociationDeleteLink($source_id) {
        return $this->createActionLink('association') . '&id=' . $source_id;
    }

    private function getTabLink() {
        return 'admin.php?page=' . $this->getParentTab()->getMenuSlug() .
                '&tab=' . $this->getMenuSlug();
    }

    private function createActionLink($action_name) {
        return 'admin.php?page=' . $this->getParentTab()->getMenuSlug() .
                '&tab=' . $this->getMenuSlug() .
                '&action=' . $action_name;
    }

    private function getSourceEditLink($source_id) {
        return $this->createActionLink('edit') . '&id=' . $source_id;
    }

    private function getSourceDeleteLink($source_id) {
        return $this->createActionLink('delete') . '&id=' . $source_id;
    }

}
