<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category template manager
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 26, 2013 11:36:11 AM
 * @version $Rev$
 */

/**
 * Settings class
 * Used to ....
 */
class Admin_Sources_Jobs extends WP_Page {

    protected $interfacer = null;
    private $source_type = 'job';

    public function __construct() {
        $this->interfacer = WP_Interfacer::getInstance();
    }

	public function getCapability() {
        return WP_Constants::CAPABILITY_ADMIN;
    }

    public function getMenuSlug() {
        return 'carerix_sources_jobs_page';
    }

    public function getMenuTitle() {
        return 'Jobs';
    }

    public function getPageTitle() {
        return 'Jobs';
    }

    public function page() {
		// $input_data = filter_input_array(INPUT_GET, FILTER_FLAG_STRIP_BACKTICK | FILTER_FLAG_ALLOW_OCTAL);
	    $input_data = map_deep( $_GET, 'sanitize_textarea_field' );
        if (!isset($input_data['action'])) $input_data['action']="";
        if (!isset($input_data['message'])) $input_data['message']="";
        switch ($input_data['action']) {
            case 'edit':
                $this->sourceScreen($input_data['id'], 'edit');
                break;
            case 'add':
                $this->sourceScreen();
                break;
            case 'delete':
                $this->deleteSource($input_data['id']);
                break;
            case 'association':
                $this->deleteAssociatedPosts($input_data['id']);
            case 'list':
            default:
                $this->listSources($input_data['message']);
                break;
        }
    }

    private function sourceScreen($id = false, $action = "add") {
	    if ($action == "edit") check_admin_referer( 'edit-id_' . $id );

	    // $input_data = filter_input_array(INPUT_POST, FILTER_FLAG_STRIP_BACKTICK | FILTER_FLAG_ALLOW_OCTAL);
	    $input_data = map_deep( wp_unslash($_POST), 'sanitize_textarea_field' );

        $data = array();
        if ( count($input_data) && wp_verify_nonce($input_data['_carerix_nonce_field'], 'source_edit')) {
            if (trim($input_data['name']) != '') {
	            $input_data['excerpt'] = stripslashes($input_data['excerpt']);
//                $input_data['introtext'] = stripslashes($input_data['introtext']);
	            $input_data['header'] = stripslashes($input_data['header']);
	            $input_data['bodytext'] = stripslashes($input_data['bodytext']);
	            $input_data['footer'] = stripslashes($input_data['footer']);
				unset($input_data['save']);
                $backup_data = $input_data;
                $id = false;
                if (isset($input_data['id']))
                    $id = $input_data['id'];
                $jobSource = new Entity_Source_Job($id);
                if ($id) {
                    $data = $jobSource->getData();
                    $_s = unserialize($data['settings']);
                    if (isset($_s['is_default'])) {
                        $input_data['is_default'] = 'on';
                    }
                }

                $jobSource->save($input_data);
                $id = $jobSource->getID();
                $data['edit_data'] = $backup_data;
            } else {
                $data['page_error'] = true;
                $data['title_error'] = true;
            }
        }

        $data['mediums'] = array();

        $formsTable = new WP_Table(Environment_Installation::TABLE_FORMS);
        $forms = $formsTable->getByType(WP_Constants::ENTITY_TYPE_FORM_APPLY);

        $data['apply_forms'] = $forms;

        if ($id) {
            $jobSource = new Entity_Source_Job($id);

            $sourceData = $jobSource->getData();
            $sourceData['settings'] = unserialize($sourceData['settings']);

            if (count($input_data) && !isset($data['page_error'])) {
                try {
                    $cronRunner = new Environment_CronRunner();
                    $cronRunner->runJobCronForSource($sourceData);
                } catch (Exception $ex) {
                    $data['page_error'] = true;
                    $data['sync_error'] = true;
                }
            }

            $data['edit_data'] = $sourceData;
        }
        if (!isset($data['page_error']) && count($input_data)) {
            $data['success'] = true;
        }
        $data['cancel_link'] = $this->createActionLink('list');
        $template = new Utils_Template('admin/sources/jobs_edit');
        $template->with($data)->display();
    }

    private function listSources($message = '') {

        $data = array();

        $sourcesTable = new WP_Table(Environment_Installation::TABLE_SOURCES);
        $jobSources = $sourcesTable->getByType($this->source_type);

        foreach ($jobSources as &$jobSource) {
            $jobSource['settings'] = unserialize($jobSource['settings']);
            $jobSource['editLink'] = $this->getSourceEditLink($jobSource['id']);
            $jobSource['deleteLink'] = $this->getSourceDeleteLink($jobSource['id']);
            $jobSource['pageLink'] = $this->getFrontendPage($jobSource['id']);
        }

        $data['add_new'] = $this->createActionLink('add');
        $data['jobSources'] = $jobSources;

        switch ($message) {
            case 'yes':
                $temp = new Utils_Template('admin/sources/confirmation');
                $temp->with(array('type' => 'yes'))->display();
                break;
            case 'no':
                $temp = new Utils_Template('admin/sources/confirmation');
                $temp->with(array('type' => 'no'))->display();
                break;
            default:
                break;
        }

        $template = new Utils_Template('admin/sources/jobs');
        $template->with($data)->display();
    }

    private function getFrontendPage($source_id) {
        $ents = $this->interfacer->entities_get_where_property('_carerix_job_page', $source_id);
        if (isset($ents[0])) {
            return $this->interfacer->get_post_permalink($ents[0]->post_id);
        }
        return false;
    }

    static function ajaxSaveSource($input_data) {
        $data = array();
        if (count($input_data)) {
            if (trim($input_data['name']) != '') {
                $input_data['excerpt'] = stripslashes($input_data['excerpt']);
//                $input_data['introtext'] = stripslashes($input_data['introtext']);
                $input_data['header'] = stripslashes($input_data['header']);
                $input_data['bodytext'] = stripslashes($input_data['bodytext']);
                $input_data['footer'] = stripslashes($input_data['footer']);
                $backup_data = $input_data;
                $id = false;
                if (isset($input_data['id']))
                    $id = $input_data['id'];
                $jobSource = new Entity_Source_Job($id);
                if ($id) {
                    $data = $jobSource->getData();
                    $_s = unserialize($data['settings']);
                    if (isset($_s['is_default'])) {
                        $input_data['is_default'] = 'on';
                    }
                }

	            $jobSource->save($input_data);
                $id = $jobSource->getID();
                self::deleteRestApiSyncStatuses();
            } else {
                $data['page_error'] = true;
                $data['title_error'] = true;
            }
        }

        if ($id) {
            $data['id'] = $id;
        }

        if (!isset($data['page_error']) && count($input_data)) {
            $data['success'] = true;
        }

        return $data;
    }

    private function deleteSource($id) {
	    if ( ! isset( $_REQUEST['id'] ) ) {
		    return;
	    }
	    $source_ID = (int) $_REQUEST['id'];
	    check_admin_referer( 'delete-id_' . $source_ID );

        $sourcesTable = new WP_Table(Environment_Installation::TABLE_SOURCES);
        $sourcesTable->delete($id);
	    self::deleteRestApiSyncStatuses();

	    $data = array();
        $data['source_id'] = $id;
        $data['delete_link'] = $this->getSourceAssociationDeleteLink($id);
        $data['tab_link'] = $this->getTabLink();

        $template = new Utils_Template('admin/sources/delete_associations');
        $template->with($data)->display();
    }

    private function deleteAssociatedPosts($sourceID) {
	    if ( ! isset( $_REQUEST['id'] ) ) {
		    return;
	    }
	    check_admin_referer( 'association-id_' . $sourceID );

	    $entities = $this->interfacer->entities_get_where_property('source', $sourceID);
        foreach ($entities as $entity) {
            $this->interfacer->entity_delete($entity->post_id);
        }
    }

    private function getTabLink() {
        return 'admin.php?page=' . $this->getParentTab()->getMenuSlug() .
                '&tab=' . $this->getMenuSlug();
    }

    private function getSourceAssociationDeleteLink($source_id) {
        return wp_nonce_url($this->createActionLink('association') . '&id=' . $source_id, "association-id_" . $source_id);
    }

    private function createActionLink($action_name) {
        return 'admin.php?page=' . $this->getParentTab()->getMenuSlug() .
                '&tab=' . $this->getMenuSlug() .
                '&action=' . $action_name;
    }

    private function getSourceEditLink($source_id) {
	    return wp_nonce_url($this->createActionLink('edit') . '&id=' . $source_id, "edit-id_" . $source_id);
    }

    private function getSourceDeleteLink($source_id) {
        return wp_nonce_url($this->createActionLink('delete') . '&id=' . $source_id, "delete-id_" . $source_id);
    }

	/**
	 * Remove all sync statuses files (wp-content/plugins/CxWordpress/tmp/syncstatus/*)
	 */
	private static function deleteRestApiSyncStatuses()
	{
		$cronCleaner = new Utils_CronCleaner(0);
		$cronCleaner->clearRestApiSyncStatuses();
	}
}
