<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category template manager
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Aug 26, 2013 11:36:11 AM
 * @version $Rev$
 */

/**
 * Settings class
 * Used to ....
 */
class Admin_Sources_PromotionalJobs extends WP_Page {

    protected $interfacer = null;
    private $source_type = 'promotional';

    public function __construct() {
        $this->interfacer = WP_Interfacer::getInstance();
    }

    public function getCapability() {
        return WP_Constants::CAPABILITY_ADMIN;
    }

    public function getMenuSlug() {
        return 'carerix_sources_promotionaljobs_page';
    }

    public function getMenuTitle() {
        return 'Promotional Jobs';
    }

    public function getPageTitle() {
        return 'Promotional Jobs';
    }

    public function page() {
        // $input_data = filter_input_array(INPUT_GET, FILTER_FLAG_STRIP_BACKTICK | FILTER_FLAG_ALLOW_OCTAL);
	    $input_data = map_deep( $_GET, 'sanitize_textarea_field' );

        $action = isset($input_data['action']) ? $input_data['action'] : "";
        $message = isset($input_data['message']) ? $input_data['message'] : "";
        switch ($action) {
            case 'edit':
                $this->sourceScreen($input_data['id']);
                break;
            case 'add':
                $this->sourceScreen();
                break;
            case 'delete':
                $this->deleteSource($input_data['id']);
                break;
            case 'association':
                $this->deleteAssociatedPosts($input_data['id']);
            case 'list':
            default:
                $this->listSources($message);
                break;
        }
    }

    private function listSources($message = '') {
        $sourcesTable = new WP_Table(Environment_Installation::TABLE_SOURCES);
        $promotionalSources = $sourcesTable->getByType($this->source_type);

        foreach ($promotionalSources as &$promotionalSource) {
            $promotionalSource['settings'] = unserialize($promotionalSource['settings']);
            $promotionalSource['editLink'] = $this->getSourceEditLink($promotionalSource['id']);
            $promotionalSource['deleteLink'] = $this->getSourceDeleteLink($promotionalSource['id']);
            $promotionalSource['pageLink'] = $this->getFrontendPage($promotionalSource['id']);
        }

        $data = array();

        $data['promotionalSources'] = $promotionalSources;
        $data['add_new'] = $this->createActionLink('add');

        switch ($message) {
            case 'yes':
                $temp = new Utils_Template('admin/sources/confirmation');
                $temp->with(array('type' => 'yes'))->display();
                break;
            case 'no':
                $temp = new Utils_Template('admin/sources/confirmation');
                $temp->with(array('type' => 'no'))->display();
                break;
            default:
                break;
        }

        $template = new Utils_Template('admin/sources/promotional_jobs');
        $template->with($data)->display();
    }

    private function sourceScreen($id = false) {
	    if ($id != false) check_admin_referer( 'edit-id_' . $id );

	    // $input_data = filter_input_array(INPUT_POST, FILTER_FLAG_STRIP_BACKTICK | FILTER_FLAG_ALLOW_OCTAL);
	    $input_data = map_deep( wp_unslash($_POST), 'sanitize_textarea_field' );

        $data = array();

        if (count($input_data) && wp_verify_nonce($input_data['_carerix_nonce_field'], 'source_edit')) {
            if (trim($input_data['publication_id']) != '') {
                $input_data['introtext'] = $_POST['introtext'];
                unset($input_data['save']);
                $backup_data = $input_data;
                $id = false;
                if (isset($input_data['id']))
                    $id = $input_data['id'];

                $promotionalSource = new Entity_Source_Promotional($id);
                $promotionalSource->save($input_data);
                $id = $promotionalSource->getID();
            }
            else {
                $data['page_error'] = true;
                $data['title_error'] = true;
            }

            $data['edit_data'] = $backup_data;
        }

        $formsTable = new WP_Table(Environment_Installation::TABLE_FORMS);
        $forms = $formsTable->getByType(WP_Constants::ENTITY_TYPE_FORM_APPLY);

        $data['apply_forms'] = $forms;

        if ($id) {
            $promotionalSource = new Entity_Source_Promotional($id);

            $sourceData = $promotionalSource->getData();
            $sourceData['settings'] = unserialize($sourceData['settings']);

            if (count($input_data) && !isset($data['page_error'])) {
                try {
                    $promotionalCron = new Entity_Cron_Promotional($sourceData);
                    $promotionalCron->run();

                    $finish_data = $promotionalCron->getAfterFinish();

                    $title = $finish_data['title'];
                    $promotionalSource = new Entity_Source_Promotional($id);
                    $backup_data['name'] = $title;
                    $promotionalSource->save($backup_data);
                } catch (Exception $ex) {
                    $data['page_error'] = true;
                    $data['sync_error'] = true;
                }
            }

            $data['edit_data'] = $sourceData;
        }
        $data['cancel_link'] = $this->createActionLink('list');

        $template = new Utils_Template('admin/sources/promotional_jobs_edit');
        $template->with($data)->display();
    }

    static public function ajaxSaveSource($input_data) {
        $data = array();
        $data['success'] = true;
        if (trim($input_data['publication_id']) != '') {
            $input_data['introtext'] = $_POST['introtext'];

            $backup_data = $input_data;
            $id = false;
            if (isset($input_data['id']))
                $id = $input_data['id'];

            $promotionalSource = new Entity_Source_Promotional($id);
            $promotionalSource->save($input_data);
            $id = $promotionalSource->getID();
        }
        else {
            $data['page_error'] = true;
            $data['title_error'] = true;
            $data['success'] = false;
        }

        if ($id) {
            $promotionalSource = new Entity_Source_Promotional($id);

            $sourceData = $promotionalSource->getData();
            $sourceData['settings'] = unserialize($sourceData['settings']);

            if (count($input_data) && !isset($data['page_error'])) {
                try {
                    $promotionalCron = new Entity_Cron_Promotional($sourceData);
                    $promotionalCron->run();

                    $finish_data = $promotionalCron->getAfterFinish();

                    $data['finish'] = $finish_data;
                    if ($finish_data['title'])
                        $title = $finish_data['title'];
                    else {
                        $data['page_error'] = true;
                        $data['sync_error'] = true;
                        $data['success'] = false;
                        $title = $input_data['publication_id'];
                    }
                    $data['page_title'] = $title;
                    $promotionalSource = new Entity_Source_Promotional($id);
                    $backup_data['name'] = $title;

                    $promotionalSource->save($backup_data);
                } catch (Exception $ex) {
                    $data['page_error'] = true;
                    $data['sync_error'] = true;
                    $data['success'] = false;
                }
            }
            $data['id'] = $id;
        }
        $data['input_data'] = $input_data;
        return $data;
    }

    public function deleteSource($id) {
	    check_admin_referer( 'delete-id_' . $id );

        $promotionalSource = new Entity_Source_Promotional($id);
        $promotionalSource->delete();

        $data = array();
        $data['source_id'] = $id;
        $data['delete_link'] = $this->getSourceAssociationDeleteLink($id);
        $data['tab_link'] = $this->getTabLink();

        $template = new Utils_Template('admin/sources/delete_associations');
        $template->with($data)->display();
    }

    private function getFrontendPage($source_id) {
        $ents = $this->interfacer->entities_get_where_property('source', $source_id);
        return $this->interfacer->get_post_permalink($ents[0]->post_id);
    }

    private function deleteAssociatedPosts($sourceID) {
	    if ( ! isset( $_REQUEST['id'] ) ) {
		    return;
	    }
	    check_admin_referer( 'association-id_' . $sourceID );

        $entities = $this->interfacer->entities_get_where_property('source', $sourceID);
        foreach ($entities as $entity) {
            $this->interfacer->entity_delete($entity->post_id);
        }
    }

    private function getTabLink() {
        return 'admin.php?page=' . $this->getParentTab()->getMenuSlug() .
                '&tab=' . $this->getMenuSlug();
    }

    private function getSourceAssociationDeleteLink($source_id) {
	    return wp_nonce_url($this->createActionLink('association') . '&id=' . $source_id, "association-id_" . $source_id);
    }

    private function createActionLink($action_name) {
        return 'admin.php?page=' . $this->getParentTab()->getMenuSlug() .
                '&tab=' . $this->getMenuSlug() .
                '&action=' . $action_name;
    }

    private function getSourceEditLink($source_id) {
	    return wp_nonce_url($this->createActionLink('edit') . '&id=' . $source_id, "edit-id_" . $source_id);
    }

    private function getSourceDeleteLink($source_id) {
	    return wp_nonce_url($this->createActionLink('delete') . '&id=' . $source_id, "delete-id_" . $source_id);
    }

}
