<?php

/**
 * Carerix Wordpress Plugin
 *
 * @category settings
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Sep 3, 2013 10:45:57 AM
 * @version $Rev$
 */

use Carerix\Api\Rest\Entity\CRPublication;

/**
 * Job class
 * Used to ....
 */
class Frontend_Job {

    private $interfacer = null;
    private $properties = array();
    private $source = null;
    private $publication_id = 0;
    private $labels = array();

    public function __construct($properties) {
        $this->interfacer = WP_Interfacer::getInstance();
        $this->properties = $properties;

        $job_id_property = '_carerix_job';
        $promotional_id_property = '_carerix_promotional';

        if ($this->interfacer->wpml_is_active()) {
            $job_id_property .= '_' . $this->interfacer->get_default_site_language();
        }

        if (isset($this->properties[$job_id_property])) {
            $this->publication_id = $this->properties[$job_id_property][0];
        }

        if (isset($this->properties[$promotional_id_property])) {
            $this->publication_id = $this->properties[$promotional_id_property][0];
        }

        if (!$this->publication_id) {
            $this->publication_id = $this->properties['guid'][0] ?? 0;
        }

	    $interfacer = WP_Interfacer::getInstance();
	    $this->labels = Utils_Labels::get($interfacer->get_default_site_language());
    }

    public function getSource() {
        $source = false;
        if ($this->source)
            return $this->source;

        if (isset($this->properties['source'])) {
            $source_id = $this->properties['source'][0];
        }

        if ($source_id) {
            $jobSource = new Entity_Source_Job($source_id);
            $source = $jobSource->getData();
            $source['settings'] = unserialize($source['settings']);
            if (!isset($source['settings']['apply_button_bottom']) && !isset($source['settings']['apply_button_top'])) {
                $source['settings']['apply_button_bottom'] = 'on';
            }
            $this->source = $source;
            return $source;
        }
        return $source;
    }

    public function display($content) {
        $backtrace = debug_backtrace();

//        $thefiles = array();
        foreach ($backtrace as $bkt) {
            if (isset($bkt['file'])) {
//	            $thefiles[] = $bkt['file'];
                if (basename($bkt['file']) == 'widgets.php')
                    return $content;
            }
        }

//	    $comma_separated = implode(", \n", $thefiles);
//	    Utils_Log::info("\nJob.php -> display\n" . $comma_separated . "\n\n");

        if (!$this->interfacer->frontend_displayed_single()) {
            return $content;
        }

        $post_permalink = $this->interfacer->get_post_permalink();
	    $interfacer = WP_Interfacer::getInstance();
	    $labels = Utils_Labels::get($interfacer->get_default_site_language());
	    $back_link = '<a class="cx2_backToJobDetails" href="' . $post_permalink . '">' . $labels['CxPortal.button.backToJobDetails'] . '</a>';
        if (isset($_GET['apply']) && $_GET['apply'] == 'true') { // detect /?apply=true and load apply form
            foreach ($backtrace as $bkt) {
                if (isset($bkt['file'])) {
                    if (basename($bkt['file']) == 'class-frontend.php')
                        return '';
                }
            }

			$form_id = $this->getFormIdFromJobSource();

            if ( $form_id == 0) {
                return '<span style="color: red;"> There is no mathing application form found in the WordPress configuration </span>';
            }

            $formSource = new Entity_Form($form_id);
            $formData = $formSource->getData();
            $formData['settings'] = unserialize($formData['settings']);
            $form_html = Entity_Form_EmployeeApply::display($formData['settings'], $this->publication_id);

	        return $form_html . $back_link;
        }

        if (isset($_GET['login'])) {
            $form = new Entity_Form_Login();
            $form_html = $form->display();

            return $form_html . $back_link;
        }

        if (isset($_GET['forgot'])) {
            $form = new Entity_Form_ForgotPassword();
	        $form_html = $form->display();

	        return $form_html . $back_link;
        }

        if (isset($_GET['apply_mode'])) {
            $apply_mode = new Utils_Template('fragments/frontend/apply_mode');
            $apply_link = $this->interfacer->get_post_permalink(false, 'apply=true');
            return '<form method="post" enctype="multipart/form-data" action="' . $apply_link . '">' . $apply_mode->display(true) . '</form>';
        }

        if (isset($_GET['logout'])) {
	        \Carerix\Cookie\Cookie::deleteCookie("logged_in");
	        \Carerix\Cookie\Cookie::deleteCookie("employee_id");
        }

	    $template = new Utils_Template("fragments/frontend/googleforjobs_detail");

        // $google_for_jobs = $template->display( true );
	    $google_for_jobs = $template->with($content)->display( true );
        $header = $this->get_header();
        $subheader = $this->get_subheader();
        $footer = $this->get_footer(); // Seems that this method is disabled
	    $template = new Utils_Template("fragments/frontend/conversion_detail");
	    $conversion_code = $template->display( true );

	    return $google_for_jobs . $header . $subheader . $content . $footer . $conversion_code;
    }

    private function get_subheader() {
        return '';
//        $social_icons = $this->get_social_icons('top');
//        $apply_link = $this->get_apply_link('top');
//        $content = '<div>' . $apply_link . $social_icons;
//        $content .= '</div>';
//        return $content;
    }

    private function get_header() {
        if (Environment_Settings::getLoginLinkStatus() == 'on')
            return;

        if ($this->interfacer->frontend_displayed_single() === FALSE && $this->interfacer->frontend_displayed_page() === FALSE) {
            return;
        }

	    $logged_in = \Carerix\Cookie\Cookie::getCookie("logged_in", false);
        $data = array();
        if ( $logged_in ) {
	        $NAME = \Carerix\Cookie\Cookie::getCookie("name", "");
            $data['name'] = $NAME;
            $data['logout_link'] = $this->interfacer->get_post_permalink(false, 'logout=true');
            $template_fragment = 'fragments/frontend/logged_in';
        } else {
            $data['login'] = $this->interfacer->get_post_permalink(false, 'login=true');
            $template_fragment = 'fragments/frontend/logged_out';
        }
        $template = new Utils_Template($template_fragment);
        return $template->with($data)->display( true );
    }

    private function get_footer() {
        return "";
    }


	/**
	 * Retrieves the application form ID for this vacancy
	 * Return zero if no forms are found
	 *
	 * @return int
	 */
	public function getFormIdFromJobSource()
	{
		$jobSource = $this->getSource();
		$form_id = 0;

		if (isset($jobSource['settings']['apply_form'])) {
			$form_id = (int) $jobSource['settings']['apply_form'];
		} else {
			// get the default form if no one was set
			$formsTable = new WP_Table(Environment_Installation::TABLE_FORMS);
			$all_forms = $formsTable->getAll();
			foreach ($all_forms as $form) {
				$form_settings = unserialize($form['settings']);

				if (isset($form_settings['is_default'])) {
					$form_id = (int) $form['id'];
					break;
				}
			}
		}

		return $form_id;
	}

}
