<?php

class Frontend_Shortcode
{
	/**
	 * @var array associative array consisting of keys as 'shortcodes' and 'fx' as functionname to bind
	 */
	protected $shortcodeDictionary = array();
	protected $dataDictionary = array();

	protected function register_shortcodes( $dataDictionary = array() ): Frontend_Shortcode {
		foreach ($this->shortcodeDictionary as $shortcode => $item)
		{
			$fx = $item["fx"] ?? FALSE;
			$section_key = $item["section"] ?? "";
			$heading = $item["heading"] ?? null;
			$raw = $item["raw"] ?? null;
			$type = $item["_type"] ?? "string"; // string|date
			$source = $item["_source"] ?? null;
			$override_dict = $item["_override_data_dictionary_key"] ?? "";

			if ($fx === FALSE) continue;

			add_shortcode( $shortcode,
				function ($attributes, $content, $shortcode_name) use ($fx, $section_key, $heading, $raw, $type, $source, $override_dict, $dataDictionary) {

					if ( $attributes === "" ) $attributes = array();
					// Utils_Log::info("\n 0: " . print_r($b, true) . "\n");
					$attributes['shortcode_name'] = $shortcode_name;
					$attributes['section_key'] = $section_key;
					$attributes['_type'] = $type; // meta|taxonomy. Will default to 'meta' by the vacancy_information() renderer
					$attributes['_override_data_dictionary_key'] = $override_dict; // Use annother datadictionary key instead of section_key
					if (isset($source)) $attributes['_source'] = $source;
					if (! isset($attributes['heading']) && $heading) $attributes['heading'] = $heading;
					if (! isset($attributes['raw']) && $raw) $attributes['raw'] = $raw;

					return $this->$fx( $attributes, $content, $dataDictionary );
				}
			);
		}

		return $this; // now we can do method chaining
	}

	/**
	 * Get the dictionary of the shortcode to use for user reference
	 *
	 * @return array
	 */
	public function getAll(): array {
		return $this->shortcodeDictionary;
	}
}