<?php

/**
 * Carerix Wordpress Plugin
 *
 *
 * @category entity
 * @author Bogdan Ivanov
 * @copyright Copyright (c) 2013 Carerix.com (http://www.carerix.com)
 * @link http://www.carerix.com
 * @since Jun 26, 2013 5:02:45 PM
 * @version $Rev$
 */


/**
 * Page class
 * Used to display administration pages in Wordpress
 * Used just as an abstract class
 */
abstract class WP_Page {
	
	/**
	 *
	 * @var WP_Page 
	 */
	protected $tabs = array();
	
	/**
	 *
	 * @var WP_Page 
	 */
	protected $parentTab = null;
	
	/**
	 *
	 * @var WP_Interfacer 
	 */
	protected $interfacer = null;
	
	protected $label = array();

	abstract function getPageTitle();
	abstract function getMenuTitle();
	abstract function getCapability();
	abstract function getMenuSlug();
	abstract function page();

	public function __construct() 
	{
		$this->interfacer = WP_Interfacer::getInstance();
		
		$path = $this->build_language_file_path();
		if(!is_file($path))
		{
			$path = $this->build_language_file_path('en');
		}
		$this->buildLabelsTable( $path );
		$this->interfacer->on_help(array($this, 'help'));
	}
	
	public function help($contextual_help, $screen_id, $screen)
	{
		if(stripos($screen_id, $this->getMenuSlug()) !== FALSE )
		{
			$help_container = $this->build_help_dir_path();
			if(!is_dir($help_container))
			{
				$help_container = $this->build_help_dir_path('en');
			}
			
			if(!is_dir($help_container)) return 'Help unavailable';
			
			foreach(glob($help_container .'/*') as $file)
			{
				$_t = explode('.', basename($file)) ;

				array_shift($_t);
				array_pop($_t);
				$title = implode(' ', $_t);
				$id = str_replace(' ', '_',  strtolower(basename($file)));
				$content = file_get_contents($file);
				
				$screen->add_help_tab(array(
					'id' => $id,
					'title' => $title,
					'content' => $content
				));
			}
			
		}
		return $contextual_help;
	}
	
	protected function hasTabs()
	{
		if(count($this->tabs) > 0) return true;
		return false;
	}
	
	/**
	 * 
	 * @param WP_Page $tabPage
	 */
	public function addTab($tabPage)
	{
		if(!is_a($tabPage, 'WP_Page'))
		{
			throw new DomainException('Provided object is not of type WP_Page');
		}

		$this->tabs[$tabPage->getMenuSlug()] = $tabPage;
		$tabPage->setParentTab($this);
	}
	
	/**
	 * 
	 * @param WP_Page $parentTab
	 */
	public function setParentTab($parentTab)
	{
		$this->parentTab = $parentTab;
	}
	
	/**
	 * 
	 * @return WP_Page
	 */
	public function getParentTab()
	{
		return $this->parentTab;
	}
	
	public function tabbed_page()
	{
		// @todo create the whole body and insert the page
		$this->start();
		$query_params = array();
		parse_str($_SERVER['QUERY_STRING'], $query_params);
		$tab_slug = '';
		if(isset($query_params['tab'])) $tab_slug = $query_params['tab'];
		// if no tab is set, take the first one in the tabs table
		if ( ! $tab_slug )
		{
			foreach($this->tabs as $slug => $object)
			{
				$tab_slug = $slug;
				break;
			}
		}
		$this->createHeader($tab_slug);
		
		$this->tabs[$tab_slug]->page();
		
		
		$this->end();
	}
	
	private function createHeader($tab_slug)
	{
		$header = '<h2 class="nav-tab-wrapper">';
		
		foreach( $this->tabs as $tab )
		{
			$is_active = '';
			if($tab->getMenuSlug() == $tab_slug ) $is_active = 'nav-tab-active';
			$tab_link = $this->build_tab_query($tab->getMenuSlug());
			$header .= "<a href='{$tab_link}' class='nav-tab $is_active'>{$tab->getMenuTitle()}</a>";
						
		}
		$header .= '</h2>';
		echo $header;
	}
	
	private function start()
	{
		echo '<div class="wrap"><div id="icon-themes" class="icon32"><br></div>';
	}
	
	private function end()
	{
		echo '</div>';
	}
	
	/**
	 * 
	 * @param string $slug
	 * @return string
	 */
	protected function build_tab_query($slug)
	{
		$query = 'admin.php?page='.$this->getMenuSlug().'&tab='.$slug;
		return $query;
	}
	
	private function build_language_file_path($language = FALSE)
	{
		if($language === FALSE)
		{
			$language = $this->interfacer->get_default_site_language();
		}
		
		return CARERIX_LANGUAGE_DIR . DIRECTORY_SEPARATOR . $language .
						   DIRECTORY_SEPARATOR . $this->getMenuSlug() . '.ini';
	}
	
	private function build_help_dir_path($language = FALSE)
	{
		if($language === FALSE)
		{
			$language = $this->interfacer->get_default_site_language();
		}
		
		return CARERIX_HELP_DIR . DIRECTORY_SEPARATOR . $language .
						   DIRECTORY_SEPARATOR . $this->getMenuSlug();
	}

    /** DEPRECATED FOR CARERIX **/
	private function buildLabelsTable($path)
	{
		if( ! file_exists($path) )
		{
            return;
			throw new RuntimeException('Translation file not available for: ' . basename($path) );
		}
		$this->label = parse_ini_file($path);
	}
}